"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.camelizeCube = void 0;
const inflection_1 = require("inflection");
// It's a map where key - is a level and value - is a map of properties on this level to ignore camelization
const IGNORE_CAMELIZE = {
    1: {
        granularities: true,
    }
};
function camelizeObjectPart(obj, camelizeKeys, level = 0) {
    if (!obj) {
        return obj;
    }
    if (Array.isArray(obj)) {
        for (let i = 0; i < obj.length; i++) {
            obj[i] = camelizeObjectPart(obj[i], true, level + 1);
        }
    }
    else if (typeof obj === 'object') {
        for (const key of Object.keys(obj)) {
            if (!(level === 1 && key === 'meta')) {
                obj[key] = camelizeObjectPart(obj[key], !IGNORE_CAMELIZE[level]?.[key], level + 1);
            }
            if (camelizeKeys) {
                const camelizedKey = (0, inflection_1.camelize)(key, true);
                if (camelizedKey !== key) {
                    obj[camelizedKey] = obj[key];
                    delete obj[key];
                }
            }
        }
    }
    return obj;
}
function camelizeCube(cube) {
    for (const key of Object.keys(cube)) {
        const camelizedKey = (0, inflection_1.camelize)(key, true);
        if (camelizedKey !== key) {
            cube[camelizedKey] = cube[key];
            delete cube[key];
        }
    }
    camelizeObjectPart(cube.measures, false);
    camelizeObjectPart(cube.dimensions, false);
    camelizeObjectPart(cube.preAggregations, false);
    camelizeObjectPart(cube.cubes, false);
    return cube;
}
exports.camelizeCube = camelizeCube;
//# sourceMappingURL=utils.js.map